@@ -8,19 +8,13 @@ from pkg_resources import get_distribution, DistributionNotFound
 
 import dash as _dash
 
-try:
-    from ._imports_ import *
-    from ._imports_ import __all__
+from ._imports_ import *
+from ._imports_ import __all__
 
-    from .graph import Graph
-    from .flexbox import FlexBox
+from .graph import Graph
+from .flexbox import FlexBox
 
-    __all__ += ["Graph", "FlexBox"]
-
-except ModuleNotFoundError:
-    # The _imports_ file does not exist before dash-generate-components
-    # has been called.
-    pass
+__all__ += ["Graph", "FlexBox"]
 
 try:
     __version__ = get_distribution(__name__).version
@@ -38,7 +32,7 @@ if not hasattr(_dash, "development"):
     _sys.exit(1)
 
 _basepath = _os.path.dirname(__file__)
-_filepath = _os.path.abspath(_os.path.join(_basepath, "package-info.json"))
+_filepath = _os.path.abspath(_os.path.join(_basepath, "package.json"))
 with open(_filepath) as f:
     package = json.load(f)
 
@@ -64,7 +58,10 @@ _js_dist = [
 ]
 
 _css_dist = [
-    {"relative_package_path": "webviz_core_components.css", "namespace": package_name,}
+    {
+        "relative_package_path": "webviz_core_components.css",
+        "namespace": package_name,
+    }
 ]
 
 
