@@ -4,6 +4,11 @@ from ._argument_modifier import argument_modifier
 
 
 class Graph(dcc.Graph):
+    """This Dash component can be used the same way as dcc.Graph,
+    however in addition it helps populate the graph config
+    with reasonable default values in a Webviz context.
+    """
+
     def __init__(self, *args, **kwargs):
 
         args, kwargs = argument_modifier(
@@ -13,8 +18,7 @@ class Graph(dcc.Graph):
 
     @staticmethod
     def populate_config(input_config=None):
-        """Populates an optionally given plotly config with default values
-        """
+        """Populates an optionally given plotly config with default values"""
 
         if input_config is None:
             config = {}
